@@ -1,5 +1,6 @@
 # Copyright (C) 2017 Jelmer Vernooij <jelmer@jelmer.uk>
 #
+# SPDX-License-Identifier: Apache-2.0 OR GPL-2.0-or-later
 # Dulwich is dual-licensed under the Apache License, Version 2.0 and the GNU
 # General Public License as public by the Free Software Foundation; version 2.0
 # or (at your option) any later version. You can redistribute it and/or
@@ -24,13 +25,14 @@ For details for the matching rules, see https://git-scm.com/docs/gitignore
 
 import os.path
 import re
-from typing import (TYPE_CHECKING, BinaryIO, Dict, Iterable, List, Optional,
-                    Union)
+from collections.abc import Iterable
+from contextlib import suppress
+from typing import TYPE_CHECKING, BinaryIO, Optional, Union
 
 if TYPE_CHECKING:
-    from dulwich.repo import Repo
+    from .repo import Repo
 
-from dulwich.config import Config, get_xdg_config_home_path
+from .config import Config, get_xdg_config_home_path
 
 
 def _translate_segment(segment: bytes) -> bytes:
@@ -79,7 +81,6 @@ def translate(pat: bytes) -> bytes:
     Originally copied from fnmatch in Python 2.7, but modified for Dulwich
     to cope with features in Git ignore patterns.
     """
-
     res = b"(?ms)"
 
     if b"/" not in pat[:-1]:
@@ -114,7 +115,6 @@ def read_ignore_patterns(f: BinaryIO) -> Iterable[bytes]:
       f: File-like object to read from
     Returns: List of patterns
     """
-
     for line in f:
         line = line.rstrip(b"\r\n")
 
@@ -150,7 +150,7 @@ def match_pattern(path: bytes, pattern: bytes, ignorecase: bool = False) -> bool
 class Pattern:
     """A single ignore pattern."""
 
-    def __init__(self, pattern: bytes, ignorecase: bool = False):
+    def __init__(self, pattern: bytes, ignorecase: bool = False) -> None:
         self.pattern = pattern
         self.ignorecase = ignorecase
         if pattern[0:1] == b"!":
@@ -179,11 +179,7 @@ class Pattern:
         )
 
     def __repr__(self) -> str:
-        return "{}({!r}, {!r})".format(
-            type(self).__name__,
-            self.pattern,
-            self.ignorecase,
-        )
+        return f"{type(self).__name__}({self.pattern!r}, {self.ignorecase!r})"
 
     def match(self, path: bytes) -> bool:
         """Try to match a path against this ignore pattern.
@@ -196,8 +192,10 @@ class Pattern:
 
 
 class IgnoreFilter:
-    def __init__(self, patterns: Iterable[bytes], ignorecase: bool = False, path=None):
-        self._patterns: List[Pattern] = []
+    def __init__(
+        self, patterns: Iterable[bytes], ignorecase: bool = False, path=None
+    ) -> None:
+        self._patterns: list[Pattern] = []
         self._ignorecase = ignorecase
         self._path = path
         for pattern in patterns:
@@ -242,15 +240,15 @@ class IgnoreFilter:
     def __repr__(self) -> str:
         path = getattr(self, "_path", None)
         if path is not None:
-            return "{}.from_path({!r})".format(type(self).__name__, path)
+            return f"{type(self).__name__}.from_path({path!r})"
         else:
-            return "<%s>" % (type(self).__name__)
+            return f"<{type(self).__name__}>"
 
 
 class IgnoreFilterStack:
     """Check for ignore status in multiple filters."""
 
-    def __init__(self, filters):
+    def __init__(self, filters) -> None:
         self._filters = filters
 
     def is_ignored(self, path: str) -> Optional[bool]:
@@ -294,21 +292,16 @@ class IgnoreFilterManager:
     def __init__(
         self,
         top_path: str,
-        global_filters: List[IgnoreFilter],
+        global_filters: list[IgnoreFilter],
         ignorecase: bool,
-    ):
-        self._path_filters: Dict[str, Optional[IgnoreFilter]] = {}
+    ) -> None:
+        self._path_filters: dict[str, Optional[IgnoreFilter]] = {}
         self._top_path = top_path
         self._global_filters = global_filters
         self._ignorecase = ignorecase
 
     def __repr__(self) -> str:
-        return "{}({}, {!r}, {!r})".format(
-            type(self).__name__,
-            self._top_path,
-            self._global_filters,
-            self._ignorecase,
-        )
+        return f"{type(self).__name__}({self._top_path}, {self._global_filters!r}, {self._ignorecase!r})"
 
     def _load_path(self, path: str) -> Optional[IgnoreFilter]:
         try:
@@ -332,7 +325,7 @@ class IgnoreFilterManager:
           Iterator over Pattern instances
         """
         if os.path.isabs(path):
-            raise ValueError("%s is an absolute path" % path)
+            raise ValueError(f"{path} is an absolute path")
         filters = [(0, f) for f in self._global_filters]
         if os.path.sep != "/":
             path = path.replace(os.path.sep, "/")
@@ -380,10 +373,8 @@ class IgnoreFilterManager:
             os.path.join(repo.controldir(), "info", "exclude"),
             default_user_ignore_filter_path(repo.get_config_stack()),
         ]:
-            try:
+            with suppress(OSError):
                 global_filters.append(IgnoreFilter.from_path(os.path.expanduser(p)))
-            except OSError:
-                pass
         config = repo.get_config_stack()
         ignorecase = config.get_boolean((b"core"), (b"ignorecase"), False)
         return cls(repo.path, global_filters, ignorecase)
